import logging

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)
stream_handler = logging.StreamHandler()
formatter = logging.Formatter('%(asctime)s - %(levelname)s:  %(message)s')
stream_handler.setFormatter(formatter)
logger.addHandler(stream_handler)
